/*
 * Copyright (C) 2023 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
    "encoding/json"
    "flag"
    "fmt"
    "log"
    "os"
    "ssa/pims_analyzer/pkg/db"
    "ssa/pims_analyzer/pkg/pims"
    "gitlab.nrao.edu/ssa/gocapo/helpers"
)

func main()  {

    // We need the CAPO profile
    var capoProfile, capoPath string
    var workflowID int

    flag.StringVar(&capoPath, "prop", helpers.DefaultCapoPath, "[Optional] Path to the CAPO properties file, defaults to " + helpers.DefaultCapoPath)
    flag.StringVar(&capoProfile, "profile", os.Getenv("CAPO_PROFILE"), "The CAPO profile to use, defaults to CAPO_PROFILE env variable")
    flag.IntVar(&workflowID, "id", -1, "The ID of the PIMS split workflow in Workspaces (Required)")
    flag.Parse()

    // Go doesn't let me require a value in a flag without setting a default :(
    if (workflowID < 0) {
        log.Fatalln("Must specify a Workflow ID!")
    }

    pimsInfo := pims.GetPimsInfo(workflowID, capoPath, capoProfile)

    outJson, err := json.Marshal(pimsInfo)
    db.CheckError(err)

    fmt.Println(string(outJson))
}
