# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""simple-machine-notifications

Revision ID: 8534eaec5381
Revises: 11fbc3f2c782
Create Date: 2022-07-25 15:23:10.114325

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "8534eaec5381"
down_revision = "11fbc3f2c782"
branch_labels = None
depends_on = None


old_submitted_content = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Submitted


      Dear User,

      Your {{version.capability_name}} request has been submitted.

      You will be notified when it is complete.

      The status of your request can be tracked here:

      {{{version.request.status_url}}}

      Best regards,

      NRAO Workspaces
"""

old_failed_content = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Failed


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{version.capability_name}} request #{{version.capability_request_id}} has failed.

    Best regards,
    NRAO Workspaces
"""

old_success_content = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Complete


    Dear User,

    Thank you for using NRAO Workspaces.

    Your {{version.capbility_name}} request is now complete.

    Best regards,
    NRAO Workspaces
"""

new_submitted_content = """Dear User,

Your {{version.capability_name}} request #{{version.capability_request_id}} (Version #{{version.version_number}}) has been submitted.

You will be notified when it is complete.

The status of your request can be tracked here:

{{version.status_url}}

Best regards,

NRAO Workspaces
"""

new_failed_content = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Failed


Dear User,

Thank you for using NRAO Workspaces.

Your {{version.capability_name}} request #{{version.capability_request_id}} (Version #{{version.version_number}}) has failed.



Best regards,
NRAO Workspaces

"""

new_success_content = """To: {{destination_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Complete


Dear User,

Thank you for using NRAO Workspaces.

Your {{version.capbility_name}} request #{{version.capability_request_id}} (Version #{{version.version_number}})  is now complete.

You can review your request here:

{{version.status_url}}


Best regards,
NRAO Workspaces
"""


def upgrade():
    # Submitted:
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_submitted_content}' WHERE name='workflow-submitted'
        """
    )
    # Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_failed_content}' WHERE name='workflow-failed'
        """
    )

    # Complete
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{new_success_content}' WHERE name='workflow-complete'
        """
    )


def downgrade():
    # Submitted:
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_submitted_content}' WHERE name='workflow-submitted'
        """
    )
    # Failed
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_failed_content}' WHERE name='workflow-failed'
        """
    )

    # Complete
    op.execute(
        f"""
        UPDATE notification_templates
        SET template=E'{old_success_content}' WHERE name='workflow-complete'
        """
    )
